import { BatchExecuteStatementCommandInput, BatchExecuteStatementCommandOutput, BatchGetCommandInput, BatchGetCommandOutput, BatchWriteCommandInput, BatchWriteCommandOutput, DeleteCommandInput, DeleteCommandOutput, ExecuteStatementCommandInput, ExecuteStatementCommandOutput, ExecuteTransactionCommandInput, ExecuteTransactionCommandOutput, GetCommandInput, GetCommandOutput, PutCommandInput, PutCommandOutput, QueryCommandInput, QueryCommandOutput, ScanCommandInput, ScanCommandOutput, TransactGetCommandInput, TransactGetCommandOutput, TransactWriteCommandInput, TransactWriteCommandOutput, UpdateCommandInput, UpdateCommandOutput } from "@aws-sdk/lib-dynamodb";
import { HttpHandlerOptions as __HttpHandlerOptions } from "@aws-sdk/types";
import { ConditionalCheckFailedError, DuplicateItemError, IdempotentParameterMismatchError, InternalServerError, InvalidEndpointError, ItemCollectionSizeLimitExceededError, ProvisionedThroughputExceededError, RequestLimitExceededError, ResourceNotFoundError, SdkError, TransactionCanceledError, TransactionConflictError, TransactionInProgressError } from "@effect-aws/client-dynamodb";
import { Context, Effect, Layer } from "effect";
import { DynamoDBDocumentClientInstance } from "./DynamoDBDocumentClientInstance";
/**
 * @since 1.0.0
 * @category models
 */
export interface DynamoDBDocumentService {
    readonly _: unique symbol;
    /**
     * @see {@link BatchExecuteStatementCommand}
     */
    batchExecuteStatement(args: BatchExecuteStatementCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | InternalServerError | RequestLimitExceededError, BatchExecuteStatementCommandOutput>;
    /**
     * @see {@link BatchGetCommand}
     */
    batchGet(args: BatchGetCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError, BatchGetCommandOutput>;
    /**
     * @see {@link BatchWriteCommand}
     */
    batchWrite(args: BatchWriteCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError, BatchWriteCommandOutput>;
    /**
     * @see {@link DeleteCommand}
     */
    delete(args: DeleteCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError, DeleteCommandOutput>;
    /**
     * @see {@link ExecuteStatementCommand}
     */
    executeStatement(args: ExecuteStatementCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | ConditionalCheckFailedError | DuplicateItemError | InternalServerError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError, ExecuteStatementCommandOutput>;
    /**
     * @see {@link ExecuteTransactionCommand}
     */
    executeTransaction(args: ExecuteTransactionCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | IdempotentParameterMismatchError | InternalServerError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError, ExecuteTransactionCommandOutput>;
    /**
     * @see {@link GetCommand}
     */
    get(args: GetCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError, GetCommandOutput>;
    /**
     * @see {@link PutCommand}
     */
    put(args: PutCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError, PutCommandOutput>;
    /**
     * @see {@link QueryCommand}
     */
    query(args: QueryCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError, QueryCommandOutput>;
    /**
     * @see {@link ScanCommand}
     */
    scan(args: ScanCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError, ScanCommandOutput>;
    /**
     * @see {@link TransactGetCommand}
     */
    transactGet(args: TransactGetCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError, TransactGetCommandOutput>;
    /**
     * @see {@link TransactWriteCommand}
     */
    transactWrite(args: TransactWriteCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | IdempotentParameterMismatchError | InternalServerError | InvalidEndpointError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionCanceledError | TransactionInProgressError, TransactWriteCommandOutput>;
    /**
     * @see {@link UpdateCommand}
     */
    update(args: UpdateCommandInput, options?: __HttpHandlerOptions): Effect.Effect<never, SdkError | ConditionalCheckFailedError | InternalServerError | InvalidEndpointError | ItemCollectionSizeLimitExceededError | ProvisionedThroughputExceededError | RequestLimitExceededError | ResourceNotFoundError | TransactionConflictError, UpdateCommandOutput>;
}
/**
 * @since 1.0.0
 * @category tags
 */
export declare const DynamoDBDocumentService: Context.Tag<DynamoDBDocumentService, DynamoDBDocumentService>;
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeDynamoDBDocumentService: Effect.Effect<DynamoDBDocumentClientInstance, never, DynamoDBDocumentService>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const BaseDynamoDBDocumentServiceLayer: Layer.Layer<DynamoDBDocumentClientInstance, never, DynamoDBDocumentService>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const DynamoDBDocumentServiceLayer: Layer.Layer<import("./DynamoDBDocumentClientInstanceConfig").DynamoDBDocumentClientInstanceConfig, never, DynamoDBDocumentService>;
/**
 * @since 1.0.0
 * @category layers
 */
export declare const DefaultDynamoDBDocumentServiceLayer: Layer.Layer<never, never, DynamoDBDocumentService>;
